User guide
==========

All the pages in the user guide are available as [jupyter](https://jupyter.org/) notebooks [here](https://github.com/man-group/PyBloqs/tree/master/docs/source).


```{toctree}
:maxdepth: 1

examples.ipynb
table_formatting.ipynb
interactive_plots.ipynb
configuration.ipynb
```
